import {Component, OnDestroy, OnInit} from '@angular/core';
import {
  Crop,
  Keyword,
  Language,
  PageableResource,
  Pest,
  Project,
  Region,
  Resource,
  ResourceType,
  Sector
} from "../../model/resource";
import {ResourceService} from "../../service/resource.service";
import {Message} from "primeng/api";
import {environment} from "../../../environments/environment";
import {SearchModel} from "../../model/search-model";
import {NavigationEnd, Router} from "@angular/router";
@Component({
  selector: 'app-home',
  templateUrl: './home.component.html',
  styleUrls: ['./home.component.css']
})
export class HomeComponent implements OnInit{
  resources: Resource[] = [];
  pageableResponse?: PageableResource;
  pageSize = 10;
  totalElements: number = 0;
  sectors: Sector[] = [];
  regions: Region[] = [];
  projects: Project[] = [];
  crops:Crop[] = [];
  pests: Pest[] = [];
  pestType: object[] = [{name:"weeds"}, {name:"disease"},{name:"invertebrate"}];
  contentTypes: ResourceType[] = [];
  languages: Language[] = [];
  keywords: Keyword[] = [];
  disclaimer: Message[] = [];
  selectedSectors: Sector[] = [];
  selectedRegions: Region[] = [];
  selectedTypes: ResourceType[] = [];
  selectedLanguages: Language[] = [];
  selectedProjects: Project[] = [];
  selectedCrops: Crop[] = [];
  selectedPests:Pest[] = [];
  selectedPestType: string | undefined;

  searchTerm: string = "";
  more= false;
  imagePath = environment.baseUrl+"/resource/image";
  imagePathRaw = environment.baseUrl+"/resource/image/raw";
  searchModel:SearchModel = {};

  constructor(private resourceService:ResourceService, private router:Router) {
    this.pageableResponse = {totalElements:0}
  }

  ngOnInit(): void {
    this.resourceService.getAllProjects().subscribe((projects: Project[]) => {
      this.projects = projects;});
    this.resourceService.getAllSectors().subscribe((sectors: Sector[]) => {
      this.sectors = sectors;});
    this.resourceService.getAllRegions().subscribe((regions: Region[]) => {
      this.regions = regions;});
    this.resourceService.getAllResourceTypes().subscribe((contentTypes: ResourceType[]) => {
      this.contentTypes = contentTypes;});
    this.resourceService.getAllLanguages().subscribe((languages: Language[]) => {
      this.languages = languages;});
    this.resourceService.getAllPests().subscribe((pests: Pest[]) => {
      this.pests = pests;});
    this.resourceService.getAllCrops().subscribe((crops: Crop[]) => {
      this.crops = crops;});
    this.resourceService.getAllResources().subscribe((resources: PageableResource) => {
      // @ts-ignore
      this.resources = resources.content;
      // @ts-ignore
      this.totalElements = resources.totalElements;
    });
    this.disclaimer = [{severity:"info", summary:"Disclaimer", detail:"This IPMWORKS Resource Toolbox is a repository for IPM resource developed by the EU IPMWORKS project (101000339). The cooperating partners have no economic responsibility whatsoever for losses due to using this service."}];
    }

    public toggleFilters(){
    //kada se zatvore dodatni filteri isprazniti ako je nesto bilo selektovano u tim filterima
    this.more = !this.more;
    }
    public searchResource(){
      // @ts-ignore
      this.resourceService.searchResource(this.searchModel).subscribe((resources: Resource[]) => {
        this.resources = resources;
        this.totalElements = resources.length
      });
    }

  onPageChange(event:any) {
    var pNum = event.first / event.rows
    this.resourceService.getAllResources(pNum, event.rows,)
      .subscribe(ret => this.populate(ret));
  }
  populate(ret: PageableResource) {
    this.pageableResponse = ret;
    // @ts-ignore
    this.resources = this.pageableResponse?.content;
    // @ts-ignore
    this.totalElements = this.pageableResponse.totalElements;
  }
  public resetSearch(){
    this.resourceService.getAllResources().subscribe((resources: PageableResource) => {
      // @ts-ignore
      this.resources = resources.content;
      // @ts-ignore
      this.totalElements = resources.totalElements;
      this.searchModel = {};
    });
  }
  isEmptySearch(){
    return JSON.stringify(this.searchModel) === '{}';

  }
}
